import json

def json_to_text(jsons, output_filename):
  with open(output_filename, "w") as f:
    for each_json in jsons:
      for line in each_json:
        f.writelines(" ".join(line) + "\n")
      f.writelines("\n")

def read_jsonl(filename):
  result = []
  with open(filename, "r") as f:
    for line in f.readlines():
      result.append(json.loads(line))
  return result



from jsonl_to_conll import convert, io
import argparse

def main():
  parser = argparse.ArgumentParser()
  parser.add_argument("input_filename", help="Input JSONL filename", type=str)
  parser.add_argument("output_filename", help="Output CONLL filename", type=str)
  args = parser.parse_args()

  data = io.read_jsonl(args.input_filename)
  data = convert.flatten_all(data)
  io.json_to_text(data, args.output_filename)

if __name__ == "__main__":
  main()
